CFEngine 3 Domain
#################

:author: Jimmy Thrasibule <jimmy.thrasibule@gmail.com>


About
=====

A domain for Sphinx providing support for CFEngine 3 policies.

The CFEngine 3 domain supports following objects:

* Attribute
* Body
* Bundle
* Component
* Function
* Namespace
* Promise
* Variable


License
=======

This SPhinx extension is brought to you under the licensing terms and
conditions stated in the ``LICENSE`` file.

**THIS SOFTWARE PROJECT IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY**
**KIND.**

